\name{A Starting Point}
\alias{A Starting Point}
\title{Some Introductory Comments}
\description{Some pointers to a few key functions in \emph{BQTL}}

\section{New to R?}{
  \itemize{
    \item Be sure to check out all of the free documentation
  that comes with R.

  \item The \code{example} function is very
  helpful in getting familiar with a new function. You type
  \code{example(fun)} and the examples in the documentation for
  \code{fun} are run, then you can read the documentaiton to get a bette
  sense of what is really going on. My personal favorite is to type
  \code{par(ask=T)}, hit the 'enter' key, then \code{example(image)},
    and 'enter' again; after each display you hit the 'enter' key to get
    to the next one.

  \item 
    \code{library(bqtl)} is needed to load the \emph{BQTL} functions and data
    sets.}
  
}
\section{Key Functions}{
  \describe{
    \item{Data Input}{ \  }
    
      \describe{
	\item{\code{\link{make.map.frame}}}{defines the map,}
	
	\item{\code{\link{marker.levels}}}{The help page describes several
	  functions that define the coding scheme for
	  marker levels, }
	
	\item{\code{\link{make.analysis.obj}}}{combines marker data, phenotype
	  data,and the \code{map.frame} to create an object that can be
	  used by data analysis functions.}
	
      }
      \item{Maximum Likelihood Methods}{ \  }
      
      \describe{
       \item{\code{\link{bqtl}}}{does a host of things from marker regression
	 and interval mapping to full maximum likelihood. The best way to
	 get started is to run \code{example(bqtl)} and take a look at
	 the resulting output.}
       
       \item{\code{\link{locus}}}{ is very helpful in specification of runs.} 
     }
     
     \item{Approximate Bayesian Analysis }{ \ }

     \describe{
       \item{\code{\link{linear.bayes}}}{
	 For a good starting point try \code{example(linear.bayes)}}}
   }
   }
   
\author{Charles C. Berry \email{cberry@ucsd.edu}}

\keyword{regression}
\eof
\name{adjust.linear.bayes}
\alias{adjust.linear.bayes}

\title{Use Laplace Approximations to improve linear approximations to
  the posterior  }
\description{
 The approximation provided by \code{linear.bayes} can be improved by
 performing Laplace approximations. This function is a development
 version of a wrapper to do that for all of the returned by
 \code{linear.bayes}. 
}
\usage{
adjust.linear.bayes(lbo, ana.obj=lbo$call$ana.obj, ...)
}

\arguments{
  \item{lbo}{ The object returned by \code{linear.bayes} }
  \item{ana.obj}{ The \code{analysis.object} used to create
    \code{lbo}. This need not be given explicitly, iff the original
    version is in the search path. }
  \item{\dots}{ ~~Describe \code{\dots} here~~ }
}

\value{A list of class \code{"adjust.linear.bayes"} containing:
  \item{odds}{A vector, typically of length k giving the odds for models
    of size 1, 2, ..., k under a uniform posterior relative to a model
    with no genes.}
  \item{loc.posterior}{The marginal posterior probabilities by locus}
  \item{coefficients}{The marginal posterior means of the coefficients}
  \item{one.gene.adj}{Results of fits for one gene models}
  \item{n.gene.adj}{Results of fits for modles with more than one gene}
  \item{call}{the call to \code{adjust.linear.bayes}}
  
}
\note{ For large \code{linear.bayes} objects invloving many gene models,
  this can require a very long time to run.}
\author{Charles C. Berry \email{cberry@ucsd.edu} }
\seealso{\code{\link{linear.bayes}}}
\keyword{regression}

\eof
\name{bqtl-internal}
\alias{\%equiv\%}
\alias{map.dx}
\alias{rhs.bqtl}
\alias{uniq.config}
\alias{zero.dup}
\alias{version.bqtl}
\title{Internal BQTL functions}
\description{
 Internal bqtl functions and objects
}
\usage{
"%equiv%"( x, y )
map.dx(lambda, theta, min.lambda)
rhs.bqtl(reg.terms, ana.obj, bqtl.specials, local.covar, scope, 
    expand.specials = NULL, method, ...) 
zero.dup(x,dig=6)
uniq.config(swap.obj)

}
\arguments{

  \item{lambda}{ (2*(recomb fraction-1/2) }
  \item{theta}{recomb fraction}
  \item{min.lambda}{smallest map distance to use}
  \item{reg.terms}{a formula}
  \item{ana.obj}{an analysis.object}
  \item{bqtl.specials}{a vector of acceptable special names}
  \item{local.covar}{a function}
  \item{scope}{vector of strings}
  \item{expand.specials}{logical,whether to use expand.grid on the loci}
  \item{method}{e'g' "F2", "BC!", etc}
  \item{...}{not sure}
  \item{swap.obj}{result of swap}
  \item{x}{numeric vector}
  \item{dig}{how many significant digits to use}

}
\details{
  These are not to be called by the user.
}
\keyword{utilities}

\eof
\name{bqtl}
\alias{bqtl}

\title{ Bayesian QTL Model Fitting }
\description{
  Find maximum likelihood estimate(s) or posterior mode(s) for QTL
  model(s). Use Laplace approximation to determine the posterior mass
  associated with the model(s). 
}
\usage{

bqtl(reg.formula, ana.obj, ...)
}
\synopsis{bqtl(reg.formula, ana.obj, scope, expand.specials, ...)}
\arguments{
 \item{reg.formula}{A formula.object like \code{ y ~ add.PVV4 *
     add.H15C12 }.  The names of the independent
   variables on the right hand side of the formula are the names of loci
   or the names of additive and dominance terms associated with loci.  In
   addition, one can use \code{locus} or \code{configs} terms to specify
one or a collection of terms in a shorthand notation.  See \code{
     \link{locus}} for more details.  The left hand side is the name
   of a trait variable stored in the search path, as a column of the
   data frame \code{data}, or \code{y} if the phenotype variable in
   \code{ ana.obj} is used. }  
 \item{ana.obj}{ The result of \code{ \link{make.analysis.obj} }. }
 \item{\dots}{ Arguments to pass to \code{lapadj}, e.g. \code{rparm} and
   \code{return.hess}}
}
\details{
  This function is a wrapper for \code{lapadj}. It does a lot
  of useful packaging through the \code{ \link{configs} } terms. If there
  is no \code{configs} term, then the result is simply the output of
  \code{ \link{lapadj}} with the \code{call} attribute replaced by the
  call to \code{bqtl}  
}
\value{
 The result(s) of calling \code{ \link{lapadj}}.
 If \code{configs} is used in the \code{reg.formula}, then the
 result is a list with one element for each formula. Each element is the
 value returned by \code{lapadj}
 
}
\references{

Tierney L. and Kadane J.B. (1986) Accurate Approximations for Posterior Moments
and Marginal Densities. \emph{JASA}, \bold{81},82--86. 

}
\author{Charles C. Berry \email{cberry@ucsd.edu} }


\seealso{\code{\link{locus}}, \code{\link{configs}}, \code{\link{lapadj}} }

\examples{

data(little.ana.bc )                        # load  BC1 dataset

loglik( bqtl( bc.phenotype ~ 1, little.ana.bc ) ) #null loglikelihood
                                                  #on chr 1 near cM 25
loglik(bqtl(bc.phenotype~locus(chromo=1,cM=25),little.ana.bc))

little.bqtl <-                              # two genes with epistasis
   bqtl(bc.phenotype ~ m.12 * m.24, little.ana.bc)
summary(little.bqtl)

several.epi <-                              # 20 epistatic models
    bqtl( bc.phenotype ~ m.12 * locus(31:50), little.ana.bc)
several.main <-                             # main effects only
    bqtl( bc.phenotype ~ m.12 + locus(31:50), little.ana.bc)

max.loglik <- max( loglik(several.epi) - loglik(several.main) )

round(
     c( Chi.Square=2*max.loglik, df=1, p.value=1-pchisq(2*max.loglik,1))
      ,2)

five.gene <-                                 ## a five gene model
  bqtl( bc.phenotype ~ locus( 12, 32, 44, 22, 76 ), little.ana.bc , return.hess=TRUE )

regr.coef.table <- summary(five.gene)$coefficients

round( regr.coef.table[,"Value"] +  # coefs inside 95\% CI
          qnorm(0.025) * regr.coef.table[,"Std.Err"] \%o\%
            c("Lower CI"=1,"Estimate"=0,"Upper CI"=-1),3)


\testonly{ rm(five.gene,little.ana.bc,little.bqtl,max.loglik,
              regr.coef.table,several.epi,several.main) }
}
\keyword{regression}


\eof
\name{coef.bqtl}
\alias{coef.bqtl}
\alias{coef.bqtl.list}
\title{ Extract Coefficients from fitted objects }
\description{
 Return a vector or matrix of coefficients as appropriate
}
\synopsis{coef.bqtl(object,...)}
\usage{
\method{coef}{bqtl}(object)
}

\arguments{
  \item{object}{The object returned by \code{bqtl}. }
  
}

\value{
 A vector (if \code{bqtl} returned a single fit) or matrix (if
 \code{bqtl} returned a list with more than one fit)
}

\author{Charles C. Berry \email{cberry@ucsd.edu} }
\seealso{\code{\link{bqtl}}}
\keyword{methods}
\eof
\name{configs}
\alias{configs}

\title{Lookup loci or effects for genetic model formulas }
\description{
Convert numeric indexes to names of regressors for a genetic model.
One or many genetic models can be specified through the use of this
function.  It is used on the right hand side of a formula in the
\code{\link{bqtl}} function. 

}
\usage{
configs(x,...,scope=<<see below>>, method = NULL)

}

\arguments{

 \item{x}{ 

Typically an integer, an integer vector, an array, or a list with a
\code{configs} component such as returned by \code{\link{swapbc1} }.
However, it can also be a character string, vector, et cetera, in which
case the elements must belong to \code{names(scope)} }

\item{\dots}{ 
Optional arguments to be used when \code{is.atomic(x)} is TRUE. }
\item{scope}{ (Optional and) 

Usually not supplied by the user.  Rather \code{bqtl} fills this in
automatically.  A vector of regressor names, like the \code{reg.names}
component returned by \code{\link{make.analysis.obj}}.  When
\code{mode(x)} is \code{"character"}, then \code{names(scope)}
\bold{must} be non-\code{NULL} }
\item{method}{ (Optional and) Usually not supplied by the user. A method
  like "F2". Typically, this is determined by internal code.
}}
\details{ \code{configs} is used in the model formula notation of
\code{bqtl}, possibly more than once, and possibly with regressors named
in the usual manner.  \code{configs} is intended to speed up the
specification and examination of genetic models by allowing many models
to be specified in a shorthand notation in a single model formula.  The
names of genetic loci can consist of marker names, names that encode
chromosome number and location, or other shorthand notations.  The names
of terms in genetic models will typically include the names of the locus
and may prepend "add." or "dom." or similar abbreviations for the
'additive' and 'dominance' terms associated with the locus. 

When used as in \code{bqtl( y ~ configs(34), my.analysis.obj )}, it will
look up the term \code{my.analysis.obj$reg.names[34]}.  When
this is passed back to \code{bqtl}, it get pasted into the formula and
is subsequently processed to yield the fit for a one gene model.

When used as in \code{bqtl( y ~ configs(34,75,172), my.analysis.obj)} it
looks up each term and returns a result to \code{bqtl} that results in
fitting a 3 gene model (without interaction terms). 

When \code{x} is a vector, array, or list, the processing typically
returns pieces of many model formulas.  \code{bqtl(y ~ configs(26:75),
\dots)} results in a list of 50 different one gene model fits from
\code{bqtl} for the terms corresponding to the 26th through the 75th
variables.  \code{ bqtl(y ~
configs(cbind(c(15,45,192),c(16,46,193))),\dots)} returns two four gene
models.  And more generally, whenever \code{is.array(x)} is TRUE, the
columns (or slices) specify \code{ dim(x)[1]/length(x)} different
models.  When \code{x$configs} is an array, this also happens.  This turns
out to be useful when the result of running \code{\link{swapbc1}} or
\code{\link{swapf2}} is treated as an importance sample.  In such a case,
\code{bqtl(y ~ configs(my.swap),my.analysis.obj)} will return a list in
which element \code{i} is the ith sample drawn when \code{my.swap <-
swapbc1(\dots)} was run.

}
\value{

A character vector whose element(s) can be parsed as the right hand side
of a model formula. 

}
\author{Charles C. Berry \email{cberry@ucsd.edu} }

\seealso{ 

\code{\link{bqtl}} and the examples there for a sense of how to use
\code{configs}, 
\code{\link{make.analysis.obj}} for the setup that encodes the marker
map and the marker information,
\code{\link{swapbc1}} and 
\code{\link{swapf2}} for generating samples to be screened by \code{bqtl}.

 }

\keyword{utilities}
\eof
\name{covar}
\alias{covar}

\title{Treat locus as covariate }
\description{
  Sometimes it is helps speed computations to linearize the likelihood
  or at least a part of it w.r.t. the locus allele values. Both
  'Haley-Knott regression' and 'composite interval mapping' use this
  approach. \code{covar} provides a mechanism for creating formula
  objects that specify such linearizations. 
}
\synopsis{covar(x)} 
\usage{
covar(x,...,scope=<<see below>>, method=<<see below>>)
}
\arguments{
  \item{x}{The name of a locus (except for F2 designs, when it is the
    name of an effect like 'add.m.32') or any argument of the sort that 
    \code{\link{locus}} allows.}
  \item{...}{If \code{x} evaluates to a single value, then additional
    atomic elements may be included as with \code{locus}.}
  \item{scope}{Not supplied by the user. see \link{locus}}
  \item{method}{Not supplied by the user. see \link{locus}}

}
\details{
  The function \code{covar} actually only returns \code{x}. The real
  work is done by a \code{covar} function that is hidden inside of
  \code{bqtl}, where the arguments are parsed as for \code{locus}. Each
  of the return values from \code{locus} is prefixed by "covar(" and
  suffixed by ")". If \code{x} is a name of a locus or effect, then
  \code{paste("covar(",deparse(x),")")} is returned. Later, when
  \code{bqtl} calls \code{lapadj}, terms like \code{covar(PVV4.1)} are
  recognized as requiring a linearization w.r.t. effect 'PVV4.1'.}

\value{
  a character string or vector 
}
  \references{

    HALEY, C. S. and S. A. KNOTT, 1992  A simple regression method for
    mapping quantitative trait loci in line crosses using flanking
    markers. Heredity 69:315-324.

    Knapp SJ, Bridges WC, and Birkes D. Mapping quantitative trait loci
    using molecular marker linkage maps. Theoretical and Applied Genetics
    79: 583-592, 1990.
    
    ZENG, Z.-B., 1994 Precision mapping of quantitative trait
    loci. Genetics 136:1457-1468
  }
 \author{Charles C. Berry \email{cberry@ucsd.edu}}

   \seealso{\code{\link{locus}}, \code{\link{add}}, \code{\link{dom}},
     \code{\link{configs}} 
   }


\keyword{regression}
\eof
\name{formula.bqtl}
\alias{formula.bqtl}

\title{ Extract formula from bqtl object }
\description{
  formula method for class \code{bqtl}
}
\synopsis{formula.bqtl(x,...)}
\usage{
formula.bqtl(x)
}

\arguments{
  \item{x}{The object returned by \code{bqtl} }
}

\value{ a formula object
}

\author{Charles C. Berry \email{cberry@ucsd.edu} }
\seealso{\code{\link{bqtl}}}
\keyword{methods}

\eof
\name{lapadj}
\alias{lapadj}

\title{Approximate marginal posterior for chosen model}

\usage{ lapadj(reg.formula, loc.right, marker.distances, state.matrix,
marker.names=dimnames(state.matrix)[[2]], rparm=NULL, casewt=NULL,
tol=9.9e-09, return.hess=F, mode.names=NULL, mode.mat=NULL,
nc = 1), method="BC1", maxit=100, nem=1, start.parm=NULL, ...)  }


\arguments{

  \item{reg.formula}{ A formula, like
    \code{y~add.X.3+dom.X.3+add.x.45*add.x.72}}
  \item{loc.right}{ See\code{\link{make.analysis.obj}}, which returns
    objects like this. It is a matrix of pointers to the next marker with a
    known state on the current chromosome (if any). }
  \item{marker.distances}{Distances between the markers in the
    'lambda' metric. \code{-log(lambda)/2} is the Haldane map
    distance. Linkage groups are separated by values of 0.0.  }
  \item{state.matrix}{ See\code{\link{make.analysis.obj}}, which returns
    objects like this. An n by k by q array. q is 2 for method="BC1" and
    3 for method="F2". Each element encodes the probability of the
    allele state conditional on the marker states. see
    \code{\link{make.state.matrix}} for more details.  } 
  \item{marker.names}{The names by which the markers are known.}
  \item{rparm}{

    One of the following:

    A scalar that will be used as the ridge parameter for all
      design terms except for the intercept ridge parameter which is set
      to zero 

    
   
      A vector who named elements  can be matched by the design term
      names returned in \code{$reg.vec}. If no term named
      "intercept" is provided,
      
      \code{rparm["intercept"]} will be set to zero. 

 
      A vector with \code{(q-1)*k} elements (this works when there are
      no interactions specified). If names are provided, these will be
      used for matching.

    Positive entries are 'ridge' parameters or variance ratios in a
    Bayesian prior for the regression coefficients. Larger values imply
    more shrinkage or a more concentrated prior for the regresion
    coefficients.   
  } 
  \item{tol}{Iteration control parameter  }
  \item{return.hess}{Logical, include the Hessian in the output? }
  \item{mode.names}{names to use as \code{dimnames(mode.mat)[[2]]}  }
  \item{mode.mat}{Not usually set by the user. A matrix which indicates the values of regressor
    variables corresponding to the allele states. If \code{mode.mat} is
    not given by the user,
   \code{ana.obj$mode.mat} is used.}
  \item{method}{ Currently, "BC1", "F2", "RI.self" and "RI.sib" are recognized. }
  \item{maxit}{ Maximum Number of iterations to perform}
  \item{nem}{ Number of EM iterations to use in reinitializing the
    pseudo-Hessian }
  \item{start.parm}{Vector of starting values for the maximization}
  \item{\dots}{ other objects needed in fitting }
}
\description{
  lapadj provides the Laplace approximation to the marginal posterior
  (over coefficients and dispersion parameter) for a given genetical
  model for a quantitative trait. A by-product is the parameter value
  corresponding to the maximum posterior or likelihood.
}
\details{
  The core of this function is a quasi-Newton optimizer due to Minami
  (1993) that has a computational burden that is only a bit more than
  the EM algorithm, but features fast convergence.  This is used to find
  the mode of the posterior. Once this is in hand, one can find the
  Laplace approximation to the marginal likelihood. In addition, some
  useful quantities are provided that help in estimating the marginal
  posterior over groups of models. 
}
\value{
  A list with components to be used in constructing approximations to the
  marginal posterior. These are:
  \item{adj}{The ratio of the laplace approximation to the posterior for
    the correct likelihood to the laplace approximation to the posterior
    for  the linearized likelihood}
  \item{logpost}{The logarithm of the posterior or likelihood at the mode}
  \item{parm}{the location of the mode}
  \item{posterior}{The laplace approximation of the marginal posterior
    for the exact likelihood}
  \item{hk.approx}{ Laplace approximation to the linearized likelihood}
  \item{hk.exact}{ Exact marginal posterior for the linearized likelihood}
  \item{reg.vec}{A vector of the variables used}
  \item{rparm}{
    Values of ridge parameters used in this problem.}
}
\references{ Berry C.C.(1998) Computationally Efficient Bayesian QTL Mapping
  in Experimental Crosses. \emph{ASA Proceedings of the Biometrics
  Section}. 164--169.
  
  Minami M. (1993) Variance estimation for simultaneous response growth curve
models.  Thesis (Ph. D.)--University of California, San Diego,
Department of Mathematics.
  }
  \author{Charles C. Berry \email{cberry@ucsd.edu} }
 \keyword{regression}
\eof
\name{linear.bayes}
\alias{linear.bayes}

\title{ Bayesian QTL mapping via Linearized Likelihood}
\description{
  The Bayesian QTL models via a likelihood that is linearized w.r.t. a
  fixed genetic model. By default, all one and two gene models (without
  epistasis) are fitted and a MCMC sampler is used to fit 3,4, and 5 gene
  and (optionally) larger models. 
}
\usage{
linear.bayes(x, ana.obj, partial=NULL, rparm=<<see below>>, specs=<<see below>>,
scope=<<see below>>, subset=<<see below>>, casewt=<<see below>>, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{ a formula giving the QTL and the candidate loci or a
    \code{varcov} object }
  \item{ana.obj}{An analysis.object, see \code{\link{make.analysis.obj}}
  }
  \item{partial}{a formula giving covariates to be controlled }
  \item{rparm}{ A ridge parameter. A value of 1 is suggested, but the
    default is 0. }
  \item{specs}{ An optional list with components \code{gene.number} (to
  indicate the model sizes), \code{burn.in} (to indicate the number of
  initial MCMC cycles to discard), and \code{n.cycles} (to indicate how
  many MCMC cycles to perform for each model size). If no values are
  supplied, \code{specs} defaults to
  
  \code{list(gene.number=c(1,2,3,4,5),burn.in=1,n.cycles=c(0,0,200,100,100))}}

  \item{scope}{Not generally used. If supplied this will be passed to
    \code{varcov}. } 
  \item{subset}{Not generally used. If supplied this will be passed to
    \code{varcov}.  }
  \item{casewt}{Not generally used. If supplied this will be passed to
    \code{varcov}. }
  \item{\dots}{optional arguments to pass to \code{twohk} and \code{swap} }
}
\details{
  This function is a wrapper for
  \code{\link{varcov}}, \code{\link{twohk}}, \code{\link{swap}}, and
  \code{\link{summary.swap}}, and a better understanding of optional
  arguments and the object generated is gained from their
  documentation.
}
\value{
  \item{hk}{The object returned by \code{\link{twohk}}}
  \item{swaps}{A list of objects returned by calls to
    \code{\link{swap}}. The i$^{th}$ element in \code{swaps} is for i gene
    models.}
  \item{smry}{A list of objects returned by calls to
    \code{\link{summary.swap}}. Some elements may be \code{NULL} if no
    samples were requested or if the sampling process yielded degenerate
  results. Usually, this happens if no posterior is specified for the
  regression coefficients, i.e. if \code{rparm=0} was used or implied }
  \item{odds}{A Vector of odds (relative to a no gene setup) for each
    model size evaluated. The odds are computed under a prior that
    places equal weights on models of each size considered (and are,
    therefore,  Bayes Factors). If models of size 1 and 2 are not
    evaluated or if some degenerate results were encountered, this will
    be \code{NULL}}
  \item{coefs}{A vector of posterior means of the regression
    coefficients. If models of size 1 and 2 are not
    evaluated or if some degenerate results were encountered, this will
    be \code{NULL}}
  \item{loc.posterior}{A vector of locus-wise posterior probabilities
    that the interval covered by this locus contains a gene.If models of
    size 1 and 2 are not evaluated or if some degenerate results were
    encountered, this will be \code{NULL}}
  \item{call}{The call that generated this object}
}
\references{ Berry C.C.(1998) Computationally Efficient Bayesian QTL Mapping
  in Experimental Crosses. \emph{ASA Proceedings of the Biometrics
    Section}. 164--169.
  Also available from
  \url{http://hacuna.ucsd.edu/bqtl/} }

\author{Charles C. Berry \email{cberry@ucsd.edu} }
\examples{
data( little.ana.bc )
little.lin <- linear.bayes( bc.phenotype~locus(all), little.ana.bc, rparm=1 )
par(mfrow=c(2,3))
plot( little.ana.bc, little.lin$loc.posterior, type="h" )
little.lin$odds
par(mfrow=c(1,1))
plot(fitted(little.lin), residuals(little.lin))
\testonly{rm(little.lin,little.ana.bc)}
}

\keyword{regression}

\eof
\name{little.ana.bc}
\alias{little.ana.bc}
\title{ A simulated dataset }
\description{
A simulation of a BC1 cross of 150 organisms with a genome of around 500
cM consisting of 5 chromosomes. The format is that created by
\code{\link{make.analysis.obj}}

This dataset is built up from several others. The basic data are:


\item{little.bc.pheno}{A vector of phenotype data}

\item{little.bc.markers}{A \code{map.frame} of marker data} and

\item{little.dx}{A data frame with 50 rows and 2 columns that specify
  the map locations of a simulated set of markers }

These are used to construct
\item{little.mf.5}{A \code{map.frame} with 'pseudo-markers' at least
  every 5 cM made from
  
  \code{little.mf.5 <-  make.map.frame(little.map.frame,
    nint=marker.fill( little.map.frame, reso=5, TRUE ))}
}

Then phenotype, covariate, and marker data are combined
with \code{little.mf.5}
\item{little.bc.pheno}{ A \code{data.frame} with the
  variable \code{bc.phenotype}}
\item{little.bc.markers}{A \code{data.frame} with marker state information}
}
\seealso{The examples in \code{\link{make.analysis.obj}}}


\keyword{datasets}
\eof
\name{little.ana.f2}
\alias{little.ana.f2}
\non_function{}
\title{ A simulated dataset }
\description{
A simulation of an F2 cross of 150 organisms with a genome of around 500
cM consisting of 5 chromosomes. The format is that created by \code{\link{make.analysis.obj}}
}
\keyword{datasets}
\eof
\name{little.bc.markers}
\alias{little.bc.markers}
\non_function{}
\title{ Simulated Marker Data }
\description{
  The \code{little.bc.markers} data frame has 150 rows and 50
  columns with the simulated marker data from a BC1 cross of 150
  organisms with a genome of around 500 cM consisting of 5
  chromosomes. Some \code{NA}'s have been intentionally introduced. 
}
\format{
This data frame contains the following columns:
\describe{
\item{m.1}{
a factor with levels
\code{AA} 
\code{Aa} 
}
\item{m.2}{
a factor with levels
\code{AA} 
\code{Aa} 
}
\item{m.3}{ ditto }
 \item{m.4}{ ditto }
 \item{m.5}{ ditto }
 \item{m.6}{ ditto }
 \item{m.7}{ ditto }
 \item{m.8}{ ditto }
 \item{m.9}{ ditto }
 \item{m.10}{ ditto }
 \item{m.11}{ ditto }
 \item{m.12}{ ditto }
 \item{m.13}{ ditto }
 \item{m.14}{ ditto }
 \item{m.15}{ ditto }
 \item{m.16}{ ditto }
 \item{m.17}{ ditto }
 \item{m.18}{ ditto }
 \item{m.19}{ ditto }
 \item{m.20}{ ditto }
 \item{m.21}{ ditto }
 \item{m.22}{ ditto }
 \item{m.23}{ ditto }
 \item{m.24}{ ditto }
 \item{m.25}{ ditto }
 \item{m.26}{ ditto }
 \item{m.27}{ ditto }
 \item{m.28}{ ditto }
 \item{m.29}{ ditto }
 \item{m.30}{ ditto }
 \item{m.31}{ ditto }
 \item{m.32}{ ditto }
 \item{m.33}{ ditto }
 \item{m.34}{ ditto }
 \item{m.35}{ ditto }
 \item{m.36}{ ditto }
 \item{m.37}{ ditto }
 \item{m.38}{ ditto }
 \item{m.39}{ ditto }
 \item{m.40}{ ditto }
 \item{m.41}{ ditto }
 \item{m.42}{ ditto }
 \item{m.43}{ ditto }
 \item{m.44}{ ditto }
 \item{m.45}{ ditto }
 \item{m.46}{ ditto }
 \item{m.47}{ ditto }
 \item{m.48}{ ditto }
 \item{m.49}{ ditto }
 \item{m.50}{ ditto }
\item{row.names}{row names}}
}

\keyword{datasets}

\eof
\name{little.bc.pheno}
\alias{little.bc.pheno}
\non_function{}
\title{ Simulated Phenotype Data  }
\description{
The \code{little.bc.pheno} data frame has 150 rows and 1 columns.

}
\format{
This data frame contains the following columns:
\describe{
\item{bc.phenotype}{
a numeric vector of simulated phenotype data
}
}
}
\keyword{datasets}

\eof
\name{little.map.dx}
\alias{little.map.dx}
\non_function{}
\title{ Marker Map Description for Simulated Data }
\description{
The \code{little.map.dx} data frame has 50 rows and 2 columns that specify 
 the map locations of a simulated set of markers }

\format{
This data frame contains the following columns:
\describe{
\item{marker.names}{
a factor with levels
\code{m.1} \dots \code{m.50} 
}
\item{cM}{
a numeric vector of map locations in centimorgans
}
}
}  
\keyword{datasets}
\eof
\name{little.f2.markers}
\alias{little.f2.markers}
\non_function{}
\title{ Simulated Marker Data }
\description{
The \code{little.f2.markers} data frame has 150 rows and 50 columns with
the simulated marker data from an F2 cross of 150
  organisms with a genome of around 500 cM consisting of 5 chromosomes.
}
\format{
This data frame contains the following columns:
\describe{
\item{m.1}{
a factor with levels
\code{AA} 
\code{Aa}
\code{aa} 
}
\item{m.2}{
a factor with levels
\code{AA} 
\code{Aa}
\code{aa}  
}
\item{m.3}{ ditto }
 \item{m.4}{ ditto }
 \item{m.5}{ ditto }
 \item{m.6}{ ditto }
 \item{m.7}{ ditto }
 \item{m.8}{ ditto }
 \item{m.9}{ ditto }
 \item{m.10}{ ditto }
 \item{m.11}{ ditto }
 \item{m.12}{ ditto }
 \item{m.13}{ ditto }
 \item{m.14}{ ditto }
 \item{m.15}{ ditto }
 \item{m.16}{ ditto }
 \item{m.17}{ ditto }
 \item{m.18}{ ditto }
 \item{m.19}{ ditto }
 \item{m.20}{ ditto }
 \item{m.21}{ ditto }
 \item{m.22}{ ditto }
 \item{m.23}{ ditto }
 \item{m.24}{ ditto }
\item{m.25}{
a factor with levels
\code{A-} 
\code{aa} 
}
 \item{m.26}{ ditto }
 \item{m.27}{ ditto }
 \item{m.28}{ ditto }
 \item{m.29}{ ditto }
 \item{m.30}{ ditto }
 \item{m.31}{ ditto }
 \item{m.32}{ ditto }
 \item{m.33}{ ditto }
 \item{m.34}{ ditto }
 \item{m.35}{ ditto }
 \item{m.36}{ ditto }
 \item{m.37}{ ditto }
 \item{m.38}{ ditto }
 \item{m.39}{ ditto }
 \item{m.40}{ ditto }
 \item{m.41}{ ditto }
 \item{m.42}{ ditto }
 \item{m.43}{ ditto }
 \item{m.44}{ ditto }
\item{m.45}{
a factor with levels
\code{a-} 
}
\item{m.46}{ ditto }
 \item{m.47}{ ditto }
 \item{m.48}{ ditto }
\item{m.49}{
a factor with levels
\code{AA} 
\code{Aa} 
\code{aa}
}
\item{m.50}{
a factor with levels
\code{AA} 
\code{Aa} 
\code{aa}
}
\item{row.names}{row names}}
}

\keyword{datasets}

\eof
\name{little.f2.pheno}
\alias{little.f2.pheno}
\non_function{}
\title{ Simulated Phenotype Data }
\description{
The \code{little.f2.pheno} data frame has 150 rows and 1 columns.

}
\format{
This data frame contains the following columns:
\describe{
\item{f2.phenotype}{
a numeric vector of simulated phenotype data
}
}
}

\keyword{datasets}

\eof
\name{little.map.frame}
\alias{little.map.frame}
\non_function{}
\title{ Package of Simulated Marker Map Information }
\description{
The \code{little.map.frame} data frame has 50 rows and 9 columns that
describe the marker map of \code{\link{little.map.dx}} in the format
produced by \code{\link{make.map.frame}. \code{little.map.dx} has the
  minimal data needed to construct this.}
}
\format{
This data frame contains the following columns:
\describe{
\item{marker.name}{
a factor with levels
\code{m.1} 
\code{m.2} 
\dots
\code{m.50} 
}
\item{cM}{
a vector of locations
}
\item{prior}{
weights to be used in sampling and Bayesian computations
}
\item{pos.type}{
a factor with levels
\code{left}
\code{right} 
\code{center} 
}
\item{is.marker}{
always \code{TRUE} for these data
}
\item{pos.plot}{
a vector of plotting positions
}
\item{lambda}{
transformed recombination fractions
}
\item{locus}{
an abbreviated locus name
}
\item{chr.num}{
the chromosome number 1, 2, 3, 4, or 5.
}
}
}

\keyword{datasets}

\eof
\name{little.mf.5}
\alias{little.mf.5}
\non_function{}
\title{ Package of Simulated Marker Map Information }
\description{
The \code{little.mf.5} data frame has 114 rows and 9 columns
consisting of \code{little.map.frame} plus 64 'virtual' marker loci
}
\format{
This data frame contains the following columns:
\describe{
\item{marker.name}{
The marker names taken from \code{little.map.frame} and those created to
fill virtual markers in between actual markers.
}
\item{cM}{
a vector of locations
}
\item{prior}{
weights to be used in sampling and Bayesian computations
}
\item{pos.type}{
a factor with levels
\code{left} 
\code{right} 
\code{center} 
}
\item{is.marker}{
\code{TRUE} for the 50 markers, \code{FALSE} for the 'virtual' markers
}
\item{pos.plot}{
a vector of plotting positions
}
\item{lambda}{
transformed recombination fractions
}
\item{locus}{
an abbreviated locus name
}
\item{chr.num}{
the chromosome number 1, 2, 3, 4, or 5.
}
}
}

\keyword{datasets}

\eof
\name{locus}
\alias{locus}
\alias{add}
\alias{dom}
\title{Lookup loci or effects for genetic model formulas }
\description{
Convert numeric indexes to names of regressors for a genetic model.
One or many genetic models can be specified through the use of this
function.  It is used on the right hand side of a formula in the
\code{\link{bqtl}} function. 

}
\synopsis{
locus(x, ..., scope, method, chromo, cM, ana.obj)}
\usage{
locus(x, ..., scope, method, chromo, cM, ana.obj)
add(x)
dom(x)
}

\arguments{

 \item{x}{ 

   Typically an integer, an integer vector, or an array whose elements
   are integers. These index loci described in a \code{map.frame}
   object. 
   
   However, \code{x} can also be a character string, vector, et cetera,
   in which case the elements must belong to \code{names(scope)}. }

\item{\dots}{ 
  Optional arguments (usually integers) to be used when
  \code{is.atomic(x)} is TRUE. 
}
\item{chromo }{A chromosome number or 2 ordered numbers. The loci on the
  chromosome or in the range of chromosome numbers are used. If
\code{chromo} is used, \code{x} must not be used.}
\item{cM }{(Optional) map distance or two giving a location near a locus
  or range of locations from which loci will be included. If the one
  chromosome number is specified in \code{chromo}, \code{cM} must be 
  ordered. If \code{cM} is omitted, all loci on the chromosome(s) will
  be included.}

\item{scope}{ (Optional and)
  Usually not supplied by the user.  Rather \code{bqtl} fills this in
  automatically.  A vector of regressor names, like the \code{reg.names}
  component returned by \code{\link{make.analysis.obj}}.}

\item{method}{ (Optional and) 
  Usually not supplied by the user. Like \code{scope}, \code{bqtl} takes
  care of filling this in with "BC1", "F2", et cetera as appropriate.}
\item{ana.obj}{Usually not specified by the user. This is the
  \code{analysis.object} to be used to lookup loci if a \code{chromo}
  argument is used.}  }
\details{ \code{locus} is used in the model
formula notation of \code{bqtl}, possibly more than once, and possibly
with regressors named in the usual manner.  \code{locus} is intended to
speed up the specification and examination of genetic models by allowing
many models to be specified in a shorthand notation in a single model
formula.  The names of genetic loci can consist of marker names, names
that encode chromosome number and location, or other shorthand
notations.  The names of terms in genetic models will typically include
the names of the locus and may prepend "add." or "dom." or similar
abbreviations for the 'additive' and 'dominance' terms associated with
the locus.

When used as in \code{bqtl( y ~ locus(34), my.analysis.obj )}, it will
look up the term or terms corresponding to the 34$^{th}$ locus. When
this is passed back to \code{bqtl}, it is pasted into a text string that
will become a formula and is subsequently processed to yield the fit for
a one gene model.

When used as in \code{bqtl( y ~ locus(34,75,172), my.analysis.obj)} it
looks up each term and returns a result to \code{bqtl} that results in
fitting a 3 gene model (without interaction terms). 

When \code{x} is a vector or array, the processing typically returns
pieces character strings for many model formulas.  \code{bqtl(y ~
locus(26:75), \dots)} results in a list of 50 different one gene model
fits from \code{bqtl} for the terms corresponding to the 26th through
the 75th variables.  \code{ bqtl(y ~
locus(cbind(c(15,45,192),c(16,46,193))),\dots)} returns two three gene
models.  And more generally, whenever \code{is.array(x)} is TRUE, the
columns (or slices) specify \code{ dim(x)[1]/length(x)} different
models. 

The \code{chromo} argument performs a lookup of loci on the chromosome
via the function \code{\link{map.index}}. If \code{cM} is also given,
the locus nearest that location is used. If two values are given for
\code{cM} all loci in the range are used.

\code{add(x)} and \code{dom(x)} are alternatives that specify that only
the \emph{additive} or \emph{dominance} terms in an F2 intercross. 
}
\value{

A character vector whose element(s) can be parsed as the right hand side
of a model formula(s). 

}
\author{Charles C. Berry \email{cberry@ucsd.edu} }

\seealso{ 

  \code{configs},
  \code{\link{bqtl}}, and the examples there for a sense of how to use
  \code{locus}, 
  \code{\link{make.analysis.obj}} for the setup that encodes the marker
  map and the marker information.
  
}
\keyword{regression}
\eof
\name{loglik}
\alias{loglik}
\alias{loglik.default}
\alias{loglik.bqtl}
\alias{loglik.bqtl.list}
\alias{logpost}
\alias{logpost.default}
\alias{logpost.bqtl}
\alias{logpost.bqtl.list}
\alias{posterior}
\alias{posterior.default}
\alias{posterior.bqtl}
\alias{posterior.bqtl.list}
\title{ Extract loglikelihood, log posterior, or posterior from fitted models }
\description{
A fitted model or a list of such generated by \code{bqtl} has a maximum
log likelihood or log posterior and a posterior. These functions simply
extract them.
}
\usage{
loglik(x, ...)
logpost(x, ...)
posterior(x, ...)
}

\arguments{
  \item{x}{ The object produced by \code{bqtl} }
  \item{...}{ Currently unused }
}

\value{
 A vector of numbers whose length equals the number of fitted models in \code{x}
}
\author{Charles C. Berry \email{cberry@ucsd.edu} }
\seealso{ \code{\link{bqtl}} }
\keyword{models}
\eof
\name{make.analysis.obj}
\alias{make.analysis.obj}

\title{Set up data for QTL mapping }
\description{
Create commonly used objects for the analysis of a backcross or
intercross experiment or of recombinant inbred lines.
}
\usage{
make.analysis.obj(data, map.frame, marker.frame, marker.levels=NULL,
method="F2", casewt=NULL,varcov=FALSE,mode.mat=NULL)
}

\arguments{
 \item{data}{ A \code{data.frame} (or vector) of phenotype and
   (optionally) covariate information }
 \item{map.frame}{ A \code{map.frame.object} (see \code{ \link{make.map.frame} })  encoding the map
   information and other details of the study }
 \item{marker.frame}{ A \code{marker.frame.object}.  A matrix or data.frame
   of marker state information.  }
 \item{marker.levels}{A vector of length six or \code{NULL}. If
   \code{NULL} then the defaults for the elements are:

   \tabular{lccc}{
 Element    \tab  F2.default \tab  BC.default\tab RI.default \cr
 1  \tab   \code{"AA"}           \tab     \code{"AA"}
 \tab     \code{"AA"}   \cr
 2  \tab   \code{"Aa"}           \tab     \code{"Aa"}
 \tab      \code{"aa"}  \cr
   3  \tab   \code{"aa"}           \tab    \code{"nil"}
   \tab       \code{"nil"}  \cr
   4  \tab   \code{"A-"}  \tab  \code{"nil"}
   \tab   \code{"nil"}     \cr
   5  \tab  \code{"a-"}   \tab    \code{"nil"}
   \tab   \code{"nil"}      \cr
   6  \tab  \code{"--"}     \tab    \code{"--"}
   \tab   \code{"--"} \cr
  }

   NA's are allowed in \code{marker.frame} as well as the sixth
   element(\code{"--"} by default) to denote missing data.  To use other
   coding schemes replace "AA" and "aa" by codes for homozygous states,
   "Aa" by the code for heterozygotes, "A-" by the code for 'not aa',
   "a-" by the code for 'not AA', and \code{"--"} by the missing code.
   Positions 3:5 are just placeholders if \code{method!="F2"}, but must
   be present.} 
 \item{method}{One of "F2", "BC1", "RI.self", or "RI.sib" }
 \item{casewt}{If there are multiple observations on one genotype (such
   as in recombinant inbreds) this can be used to assign a weight to
   each observation. The wisdom of doing this is debatable. }
 \item{varcov}{If FALSE, don't create a varcov.object. Otherwise give an
   index into data to select a dependent variable. See \code{ \link{varcov}}
 }
 \item{mode.mat}{If \code{NULL} use the default. For
   \code{method=="F2"} ( and the default \code{marker.levels} of
   \code{AA}, \code{Aa}, and \code{aa} ), 
   this is a 3 by 2 matrix:
   \tabular{lrr}{
     Genotype \tab add \tab dom \cr
     AA \tab -1 \tab -1 \cr
     Aa \tab 0 \tab 1 \cr
     AA \tab 1 \tab -1 \cr
   }
   For \code{method=="BC1"} ( and the default \code{marker.levels} of
   \code{AA} and \code{Aa} ),it is
   \tabular{lr}{
     Genotype \tab \cr
     AA \tab -1 \cr
     Aa \tab 1 \cr
   }
   and for RIL methods ( and the default \code{marker.levels} of
   \code{AA} and \code{aa} ),it is
   \tabular{lr}{
     Genotype \tab \cr
     AA \tab -1 \cr
     aa \tab 1 \cr
   }
   Other choices of \code{marker.levels} will relabel the corresponding
rows.
 }
}
\details{
  A lot of stuff is bundled together in one object. The function is
  really just a wrapper calling other \code{make.*} functions.
  
}
\value{
  A list with components
  \item{data }{\code{data.frame} of phenotype, covariate information,
    and regressors created by \code{ make.regressor.matrix }}
  \item{varcov}{A varcov.object. See  \code{ make.varcov } }
  \item{reg.names}{The names of the regressors from \code{
      make.regressor.matrix }}
  \item{method}{The \code{ method } argument in the call.}
  \item{state.matrix}{See \code{ make.state.matrix }}
  \item{loc.right}{See \code{ make.loc.right }}
  \item{map.frame}{See \code{ make.map.frame }}
  \item{casewt}{The \code{ casewt } argument}
  \item{mode.mat}{The \code{mode.mat} used}
  \item{version}{A string giving the version of BQTL from qhich the
    objects was created}
  \item{call}{The function call}
}

\author{Charles C. Berry \email{cberry@ucsd.edu}}
\note{ This can be quite a LARGE object.It might be better
  in crosses with lots (say, thousands) of markers, or in which many
  'virtual' markers are used, or on computers with limited RAM to
  store each component separately. Not all components are used in
  every type of analysis. }



\seealso{

  \code{\link{make.map.frame}} for definition of the marker map, The
  internally used functions are: \code{\link{make.loc.right}},
  \code{\link{make.state.matrix}}, \code{\link{make.regressor.matrix}},
  \code{\link{make.varcov}},  and \code{\link{make.marker.numeric}} }

\examples{
data( little.bc.pheno )
data( little.mf.5 )
data( little.bc.markers )
names(little.bc.pheno)
little.ana.bc <- make.analysis.obj(little.bc.pheno$bc.phenotype,
                                   little.mf.5,little.bc.markers,
                                   method="BC1")
summary( little.ana.bc )

\testonly{rm( little.ana.bc, little.bc.pheno, little.mf.5, little.bc.markers )}
}
\keyword{manip}
\eof
\name{make.loc.right}
\alias{make.loc.right}

\title{ Keep track of fully informative markers or states}
\description{
  Helps speed computations in multigene models by allowing a quick
  assessment of whether two loci are independent given the marker
  information for the individual.
}
\usage{
make.loc.right(marker.frame, marker.distances)
}

\arguments{
 \item{marker.frame}{ A \code{marker.frame.object}  } 
 \item{marker.distances}{Actually a misnomer, this is a vector with a
   zero in the last position of each chromosome.  }
}

\value{
 A matrix of the same dimension as \code{marker.frame} whose elements
 index the column on the next (right) fully informative marker.
}

\author{Charles C. Berry \email{cberry@ucsd.edu} }


\examples{

}

\keyword{manip}
\eof
\name{make.location.prior}
\alias{make.location.prior}

\title{ Provide a default prior}
\description{
 Uses the map distances as a means of assigning a prior for chromosomal
 location.  Basically, this function attempts to assign equal weight
 according to the spacing or markers and 'virtual' markers.
}
\usage{
make.location.prior( x, add.2.end=0, normalize=TRUE )
}

\arguments{
 \item{x}{ \eqn{x = e^{-mgd}}{x = exp(-mgd)} ,where mgd is the map distance in Morgans }
 \item{add.2.end}{ How many Morgans to extend the first and last
   interval on each chromosome }
 \item{normalize}{ If TRUE, let the result sum to 1.0 }
}

\value{
  A vector of \code{length(x)} whose sum is one, if \code{normalize==TRUE}
}

\author{Charles C. Berry, \email{cberry@ucsd.edu}}



\keyword{utilities}
\eof
\name{make.map.frame}
\alias{make.map.frame}

\title{Create marker map specifications}
\description{

A map.frame.object describes a marker map and additional loci that may
be used in a QTL study.  Each row pertains to one locus.  Names of
markers, abbreviated names, distances, and other necessary and useful
information are bundled.

}
\usage{
make.map.frame(dx,chr.num = NULL, prior = make.location.prior(lambda), 
    morgan = 100, nint = NULL, reso = NULL)

}

\arguments{

  \item{dx}{ An object of class \code{"map.frame"} or class
\code{"data.frame"} or a vector or a
    data.frame with a column named \code{cM}, \code{M}, or \code{dx} or
    whose first column gives location  
    on each chromosome in  centiMorgans (from start of
    chromosome or Morgans if \code{M} was the column name).  It is best
    if \code{names(dx)} (for vector arguments) 
    or \code{row.names(dx)} (for data.frame arguments) give names of
    markers for later reference, but this isn't really necessary.  } 
  \item{chr.num}{ (Optional) Vector of  chromosome  numbers}
  \item{prior}{ (Optional) Vector of Prior probabilities for the loci }
  \item{morgan}{ 100 if centiMorgans, 1 if Morgans }
  \item{nint}{ (Optional) Vector of one plus number of 'virtual' markers to be
    inserted after each locus }
  \item{reso}{Maximum distance between loci. If necessary fill in with 'pseudo-markers'}
}
\details{

  The QTL analysis depends on information about the marker map and on
  specifications of the loci to be studied.  The 'map.frame' contains
  this information. 

}
\value{
  A data frame with components:

  \item{marker.name}{The full text identifier for this marker,
    e.g.  "HH.360L.Col" is a marker on chromosome 1 of arabidopsis
    thaliana, and names like this can be used for reference
    purposes.  'Virtual' markers have a suffix appended to the name of the
    previous marker.}
  \item{cM }{Location on the chromosome.  If this is a marker of a locus
    that was input via \code{dx}, then it is just the value of \code{dx}.}
  \item{pos.type}{"left" if it is the first locus on this
    chromosome,"right" if it is last, or "center" otherwise. }
  \item{is.marker}{TRUE if this was actually a marker, FALSE if it is a
    'virtual' marker}
 \item{pos.plot}{Plotting position for this locus.  Typically the same as
   \code{dx}.}
 \item{lambda}{Twice the recombination fraction minus one.}
 \item{locus}{An abbreviation for the locus of the form
   "C.<\code{chr.num}>.<\code{cM}>"}
 \item{chr.num}{The chromosome number.}

}

\author{ Charles C. Berry \email{cberry@ucsd.edu}
	
 }

 \note{ The idea in having all of this bundled together is to make it
   easier for plot and summary methods to be implemented and to allow
   convenient references in formula based methods.}

\examples{

data( little.map.dx )
little.map.frame <- make.map.frame( little.map.dx )
plot( little.map.frame ) # there is a plot method
# add 'virtual' markers to map
little.mf.5 <-   make.map.frame(little.map.frame,reso=5)
print(little.mf.5[1:10,],digits=1) # show a few rows
plot( little.mf.5 ) # notice the 'virtual' markers added
\testonly{ rm( little.map.dx,little.map.frame ,little.mf.5) }
}

\keyword{manip}
\eof
\name{make.marker.numeric}
\alias{make.marker.numeric}

\title{Translate a marker.frame.object to numeric matrix }
\description{
  Not to be called directly by users. This utility function simply
  returns the coded numeric values corresponding to the allele states.
}
\usage{
make.marker.numeric(marker.frame, level.names=NULL)
}

\arguments{
  \item{marker.frame}{ A data.frame.object consisting of factors or
    character vectors that encode the allele states.}
  \item{level.names}{ A vector of length 6 to translate the levels
    attribute or character codes into allele states that
    \code{make.state.matrix} understands. If necessary, dummy codes are
    used to fill the vector.}
}

\value{
  A matrix, for which column i is
  \code{match(as.character(marker.frame[,i]),level.names)}
}

\author{Charles C. Berry \email{cberry@ucsd.edu} }
\keyword{utilities}
\eof
\name{make.regressor.matrix}
\alias{make.regressor.matrix}
\title{
  Create regressors using expected marker values
}
\description{
  Create regression variables for markers and loci between or near
  markers by imputation conditional on known marker states.
}
\usage{
make.regressor.matrix(state.matrix, mode.mat=NULL)
}
\arguments{
\item{state.matrix}{
A state.matrix.object - see \code{\link{make.state.matrix}} for more details
}
\item{mode.mat}{
  A matrix which indicates the values of regressor variables
  corresponding to the allele states.  If mode.mat=NULL (the default) a
  mode.mat is inferred from the dimensions of state.matrix.  For the F2
  intercross these are typically additive and dominance codes like
  (-1,0,1) and (1,-1,1).  For BC1 backcross and RI lines, typically the
  values are (-1,1).
}}
\value{
  A matrix with variables suitable for use as regressors.
}
\references{
  Haley C.S. and Knott S.A. (1992) A simple regression method for mapping
  quantitative trait loci in line crosses using flanking
  markers. \emph{Heredity} \bold{69},315-324.
}
\seealso{
  \code{\link{make.state.matrix}}
}
\keyword{utilities}
\eof
\name{make.state.matrix}
\alias{make.state.matrix}
\title{
  Create state.matrix.object
}
\description{
  Create a state.matrix.object to be used encode marker information in a
  form in which it can be used in subsequent calculations. 
}
\usage{
make.state.matrix(marker.frame, marker.distances, method="F2")
}
\arguments{
  \item{marker.frame}{
    Actually, this is a misnomer. This is NOT
    a\code{marker.frame.object}. Rather it is obtained by by call like
    \code{make.marker.numeric(marker.frame.object)} (see \code{
      \link{make.marker.numeric} }) and it is coerced to 
    a matrix. It  encodes marker allele states. One column is used for each 
    marker or pseudo-marker (basically a placeholder with all missing
    values). The entries are in 1:6, if NA's are present, they are
    recoded to 6.  The columns are arranged in
    linkage groups with presumed order reflected in the actual order of the
    columns.  
  }
  \item{marker.distances}{
    Distances between the markers in the 'lambda' metric. -log(lambda)/2
    is the Haldance map distance. Linkage groups are separated by values
    of 0.0. 
  }
  \item{method}{
  method = "F2" is the default, and   "BC1", "RI.self", and "RI.sib" are
  other options. The assumed setup is as follows (strains are A and a):

  \tabular{lccc}{
    marker state \tab  F2.code \tab  BC.code\tab RI.code \cr
    \code{"AA"}  \tab    1    \tab     1   \tab    1\cr
    \code{"Aa"} \tab     2  \tab      2 \tab \cr
    \code{"aa"}  \tab    3   \tab        \tab      2 \cr
    \code{"A-"} (not aa)    \tab  4      \tab   \tab     \cr
    \code{"a-"} (not AA) \tab    5    \tab     \tab        \cr
    \code{"--"} (unknown) \tab    6 \tab        6   \tab    6\cr
  }
}}
\value{
  n by k by q array. q is  3 for method="F2" and 2 for others methods.  Each
  element encodes the probability of the allele state conditional on the
  marker states. 
}
\references{
 Lander E.S. and Green P. (1987) Construction of multilocus genetic linkage maps
 in humans. \emph{Proceedings of the National Academy of Sciences of the
 United States of America}, \bold{84}(8), 2363--7.
 
  Jiang C. and Zeng Z-B.  (1997) Mapping quantitative trait loci with dominant and
  missing markers in various crosses from tow inbred lines. \emph{Genetica}
  \bold{101}, 47-58.  
}
\note{
  It might have been better to design this array so that the third
  subscript moves fastest.  In large problems, the current structure may
  involve excessive memory access.}
\keyword{utilities}
\eof
\name{make.varcov}
\alias{make.varcov}
\title{ Create moment matrices}
\description{
  Create a moment matrix of the marker variables and of the regressors by
  the phenotype variable.  For use in regression modelling on the markers.
}
\usage{
make.varcov(regressor.matrix, y, subset=is.finite(y), casewt=NULL)
}

\arguments{
 \item{regressor.matrix}{The object produced by \code{\link{make.regressor.matrix}} }
 \item{y}{ A vector of phenotype information with the same number of
   elements as there are rows in \code{regressor.matrix} }
 \item{subset}{ Logical vector with the same number of
   elements as there are rows in \code{regressor.matrix} to indicate
   which rows to keep.  }
 \item{casewt}{Optional vector of case weights. }
}

\value{
 A list with components
  \item{var.x }{Moment matrix of the marker regressor variables}
  \item{cov.xy }{Moment matrix of the marker regressor variables versus
    the phenotype variable}
  \item{var.y}{The Second central moment of the phenotype variable}
  \item{df}{ \code{ sum(subset==TRUE) - 1}
}}
\author{Charles C. Berry \email{cberry@ucsd.edu} }
\note{ It is generally NOT a good idea to do regressions on
  ill-conditioned designs using the moment matrices like this.  The
  excuse for doing so here is twofold.  First, calculations using this
  method are used to perform importance sampling, so minor numerical
  inaccuracies in computing the probabilites used in sampling get
  straightened out by the importance weights.  Second, it will typically
  be the case that a prior is set on the regression coefficients and
  this results in a positive constant (aka a 'ridge' parameter) being
  added to diagonal of \code{varcov$var.x} and this reduces the
  ill-conditioning.  Of course the rational for using the method is to
  speed the sampling, and it is very effective at doing so.} 

\keyword{utilities}
\eof
\name{map.index}
\alias{map.index}
\alias{map.index.default}
\alias{map.index.analysis.object}
\title{Look up numerical index(es) of map locations}
\description{
One way to index a locus (loci) in a genetic map is by the numerical index of
its row (their rows). \code{map.index} performs a lookup in a specific
\code{map.frame} given one (or two) chromosome number(s) and one (or
two) map distance(s).
}
\usage{
map.index(x, ... )
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x }{A \code{map.frame} or \code{analysis.object}}
  \item{...}{ For methods that look up a location in a \code{map.frame}
    the following named arguments may be used:
  \code{chromo }{A chromosome number or 2 ordered numbers }
  \code{cM }{(Optional) map distance or two. If the same chromosome
    number is used twice in \code{chromo}, \code{cM} must be
    ordered. If \code{cM} is omitted, all loci on the chromosome will
  be included.}
}}
\details{
  It is often convenient to refer to genetic loci or regions by the
  numerical index(es) in a \code{map.frame}. \code{map.index} allows
  lookups according to the approximate map location.
}
\value{
A numerical vector of one or more row numbers. If only \code{chromo} is
specified, all row numbers on the specified chromosome are returned. If
\code{chromo} has two elements, then all row numbers on those
chromosomes with numbers in \code{range(chromo)} will be returned. If
one of each of \code{chromo} and \code{cM} are specified, then the row
number of the closest locus will be returned. For two of each, row
numbers in the range of the closest matches will be returned.
}
\author{Charles C. Berry \email{cberry@ucsd.edu}}
\seealso{ \code{\link{make.map.frame}} for a description of how map
  information is organized.}
\examples{
data(little.ana.bc)
map.index(little.ana.bc,chromo=1,cM=25) # locus nearest 1,25
index.chr.1 <- map.index(little.ana.bc,chromo=1)
fit.on.1 <- bqtl(bc.phenotype~locus(index.chr.1),little.ana.bc)
summary( loglik( fit.on.1 ) )

}

\keyword{methods}
\eof
\name{map.location}
\alias{map.loc}
\alias{map.location}
\alias{map.location.default}
\alias{map.location.analysis.object}
\alias{map.location.bqtl}
\alias{map.location.bqtl.list}
\title{ Report map location  }
\description{
 Report the chromosome number and location of loci in a genetic map.
}
\usage{
map.location(x,\dots )
map.loc(x, \dots )
}

\arguments{
  \item{x}{A object of class \code{map.frame},\code{analysis.object},
\code{bqtl}, or \code{bqtl.list}}
  \item{\dots}{Other arguments usage depend on the class of \code{x} :
  \code{y}{A vector of row numbers or \code{map.names} specifying which
    subset of the \code{map.frame} of \code{x} is to be returned}
  \code{chromo}{A vector of chromosome numbers}
  \code{cM }{(Optional) map distance vector. If the same chromosome
    number is used twice in \code{chromo}, \code{cM} must be
    ordered. If \code{cM} is omitted, all loci on each chromosome listed
    in \code{chromo} will be included.}

  \code{map.names}{A vector of \code{map.names}}
}}
\details{ It is often helpful to refer to genentic loci by their
locations. The methods of \code{map.location} (alias \code{map.loc})
will extract the row index, chromosome number and location, and the name
for specified loci. For direct lookups of the loci in a \code{map.frame}
or \code{analysis.object}, one must specify \code{y} or \code{chromo} or
\code{map.names}. When \code{class(x)=="bqtl"} \code{map.location}s of
terms used in a call to \code{bqtl} are returned. When \code{cM} is
used, an attempt will be made to match the location; if the match fails,
the nearest locus will be used. When there are two elements in
\code{chromo} and two in \code{cM}, all the map locations in between the
matching loci will be returned.

}
\value{
An object of class \code{map.location} which inherits from
\code{map.frame}. It has columns:

  \item{chr.num }{The chromosome number}
  \item{cM }{The location in centiMorgans on that chromosome.}
  \item{marker.name }{The name by which that marker is known}
  
  \item{attr(,"row.names")}{An index of the locations}

}
\author{Charles C. Berry \email{cberry@ucsd.edu}}

\seealso{\code{\link{make.map.frame}}}

\examples{

data(little.ana.bc)

map.loc(little.ana.bc, c(1,15,45))
map.loc(little.ana.bc,chromo=3,cM=22)
map.loc(little.ana.bc,"m.12")
rm(little.ana.bc)
}
\keyword{regression}
\eof
\name{map.names}
\alias{map.names}
\alias{map.names.default}
\alias{map.names.bqtl}
\alias{map.names.bqtl.list}
\alias{map.names.analysis.object}
\alias{map.names.map.frame}
\title{Look up names of markers or loci}
\description{This is  a generic helper function with methods  that will
  return the names of markers or loci. 

}
\usage{
map.names(x,...)
map.names.map.frame(x,...)
map.names.bqtl(x, ..., ana.obj)
}

\arguments{
  \item{x}{ An object that has marker names in it. Methods for objects
    of the 
    \code{map.frame}, \code{analysis.object},\code{bqtl}, and
    \code{bqtl.list} class.}
  \item{\dots}{For \code{class(x)=="analysis.object"} or
    \code{class(x)=="map.frame"}, arguments \code{chromo} and \code{cM}
    can be used as in \code{map.index}
  }
  \item{ana.obj}{(optional) analysis object in which to look up the names}
}
\value{
A character vector 
}
\author{Charles C. Berry \email{cberry@ucsd.edu} }

\seealso{ \code{\link{map.index}}, \code{\link{map.location}}}

\examples{
data(little.ana.bc)

map.names(little.ana.bc,chromo=1,cM=24)

map.names(little.ana.bc,chromo=c(1,1),cM=c(40,55))

fit <- bqtl( bc.phenotype ~ locus(23,42) , little.ana.bc )

map.names( fit )

\testonly{rm(fit, little.ana.bc)}
}
\keyword{utilities}

\eof
\name{marker.fill}
\alias{marker.fill}
\title{
Map Positions Between Markers
}
\description{


Given a set of markers, one wants to create a finer map at a given
resolution. marker fill takes a a collection of marker distances and a
desired resolution and finds positions that are intermediate and at
that resolution.


}
\usage{
marker.fill(map.frame, reso, return.nint = FALSE)


}
\arguments{
\item{map.frame}{

A map.frame.object.

}
\item{reso}{
The desired interval between loci in the same metric as \code{map.frame$cM}
}
\item{return.nint}{Whether to output a vector of number of intervals to
  produce in each existing interlocus interval}
}
\value{
If \code{return.nint} is \code{TRUE}, a vector of integers is
returned. It indicates how many intervals to place between this marker
and the next to achive the desired minimum distance.

If \code{return.nint} is \code{FALSE}, a vector of distances is
returned. The names attribute has suffixes 
added to indicate positions filled to the 'right' of existing
markers. Thus if markers 'mark.01' and 'mark.02' are in succession at
a distance of 3 and reso==1, then the value associated with 'mark.01'
(which was 3) becomes 1, a value of 1 is associated with new loci
called 'mark.01.1' and 'mark.01.2' in created with values of 1
each. The returned vector is ordered by chromosome, then marker or
filled locus.
}

\seealso{
  \code{\link{make.map.frame}}
}

\examples{


data( little.map.frame  )
little.nint <- marker.fill( little.map.frame, reso=5, TRUE )
cbind(nint=little.nint,cM=little.map.frame$cM)[1:10,]
rm( little.map.frame, little.nint )
}
% Converted by Sd2Rd version 1.10.
\keyword{utilities}
\eof
\name{marker.levels}
\alias{marker.levels}
\alias{bc1.levels}
\alias{f2.levels}
\alias{ri.levels}
\title{ Define marker level codes }
\description{
The coding scheme used to define marker.levels is set up by these
functions. \emph{BQTL} has defaults that these functions can help the
user to redefine.
}
\usage{
bc1.levels( AA="AA", Aa="Aa", miss.val="--")
ri.levels(  AA="AA", aa="aa", miss.val="--")
f2.levels(  AA="AA", Aa="Aa", aa="aa", not.aa="A-", not.AA="a-",
miss.val="--")

}
\arguments{
  \item{AA}{Always used: the code for the homozygous state from one parent line}
  \item{Aa}{F2 and BC1 setups: the code for the heterozygous state }
  \item{aa}{F2 and RI setups: the code for the homozygous state for the
    other parent line }
  \item{not.aa}{F2 only: the code for a dominant marker that rules out  \code{aa} }
  \item{not.AA}{F2 only: the code for a dominant marker that rules out \code{AA} }
  \item{miss.val}{The character string for a missing (unknown) allele
    state. \code{NA}s are automatically detected, so this is only needed
    if string values are used to denote missing values.}
}
\details{It is essential that the codes intended by the user be
clearly understood by \emph{BQTL}. It is hoped that thees functions
provide a bridge between the internals of \emph{BQTL} and the user's
view of the marker codes. Numeric values can be used, but they will be
coerced to character values.}
\value{A vector with 6 elements corresponding to the values of 
  \code{AA, \code{Aa}, \code{aa}, \code{not.aa}, \code{not.AA}, and
    \code{miss.val}. For RI and BC1 setups, those that do not apply will
    be unnamed and set to \code{"nil"}
}}
\author{ Charles C. Berry \email{cberry@ucsd.edu}}
\seealso{ \code{\link{make.analysis.obj}} }

\examples{

### show the defaults:

f2.levels()
bc1.levels()
ri.levels()

### suppose that 1,2,3 are codes used in F2:

f2.levels(1,2,3)

### show what would happen changing "Aa" to "H"

f2.levels(Aa="H")
bc1.levels(Aa="H")

}
\keyword{manip}

\eof
\name{plot.map.frame}
\alias{plot.map.frame}
\alias{plot.analysis.object}
\title{ plots by chromosome location }
\description{
  Multiple x-y plots are formed using chromosome numbers
  (\code{chr.num}) and positions (\code{pos.plot}) specified in a object
  of the sort created by \code{\link{make.map.frame}}
}
\usage{
\method{plot}{map.frame}(x, y, ...)
}
\synopsis{
plot.map.frame(x, y, fun, type, include.rug, rug.lwd,
                 title.string, y.range, ylab, xlab, ...)
}

\arguments{
 \item{x}{A \code{map.frame.object} or an \code{analysis.object}  }
 \item{y}{(optional) A vector with as many elements or a
   matrix with as many rows as \code{nrow(x)} .  If omitted, a plot
   will be drawn in a single frame representing the chromosomes as
   horizontal bars and giving tic marks to show the locations markers
   and virtual markers (if any).  }
 \item{\dots}{ more args:
 \code{fun}{ A plotting function to be used \emph{after} the plot axes and
   labels have been drawn.  The current default \code{if (y.type ==
     "matrix") matlines else lines} usually is good enough.  But a
   fancier function could be used for a fancier plot. }
 \code{type}{ \code{"l"} for lines, "p" for points, et cetera.  see \code{\link{par}} }
 \code{include.rug}{ if \code{TRUE} place a tick on the x-axis at each marker location }
 \code{title.string}{(optional) label to prepend to each title }
 \code{ylab}{plot label for y-axis, see \code{\link{par}}  }
 \code{xlab}{plot label for x-axis, see \code{\link{par}}  }
  }
}
\details{
  This function enables drawing graphs that depend on chromosome and
  chromosome location.  Typically, one will use a command like
  \code{par(mfrow=c(nrows,ncols))} first to set up a page on which
  multiple plots will be drawn.  However, one can draw one plot per page
  on postscript devices by leaving \code{par(mfrow=c(1,1))}
}
\value{
  \code{NULL} - this function is called only for its side effects
}

\author{Charles C. Berry \email{cberry@ucsd.edu} }

\seealso{
  \code{\link{plot}},
\code{\link{lines}}, and 
\code{\link{matlines}} for general information on plotting functions;
\code{\link{par}} for optional arguments to add as arguments; and 
\code{\link{make.map.frame}} for the details on the object the drives this function.

}

\examples{

data( little.ana.bc )
null.llk <- loglik(bqtl(bc.phenotype~1,little.ana.bc))
llk <- loglik( bqtl( bc.phenotype~locus(all), little.ana.bc) ) - null.llk
.old.par <- par(mfrow=c(2,3))
plot.map.frame(little.ana.bc$map.frame,llk)
par(.old.par)
\testonly{ rm(null.llk, llk, little.ana.bc, .old.par ) }

}
\keyword{hplot}
\eof
\name{predict.bqtl}
\alias{predict.bqtl}
\alias{fitted.bqtl}
\title{ fitted values from QTL models}
\description{
 The estimated coefficients and expected locus values are used to find
 fitted values for the QTL model
}
\synopsis{
predict.bqtl(object, newdata,...)
fitted.bqtl(object, newdata,...)
}
\usage{
\method{predict}{bqtl}(object, newdata)
\method{fitted}{bqtl}(object, newdata)
}
\arguments{
  \item{object}{ An object of class \code{\link{bqtl}}}
  \item{newdata}{An optional data.frame for which fitted values are to
    be found. If not specified, the a search for the original data frame
    for the fit will be made. }
}
\details{
 The estimated coefficients for a specific QTL model fit are used along
 with the  expected locus values (conditionally on the marker values)
 are used to find fitted values for the QTL model. This is \emph{not} the only
 way in which such fits could be obtained; one could condition the
 expect marker values on \emph{both} the trait value and the marker
 values. One could also define fitted values for specific genotype
 combinations, e.g. for a backcross with k animals and a two gene model
  4 fitted values could be determined for each animal leading to 2*2*k
  values. In fact, using \code{newdata} one can do this.
}
\value{ A vector with as many elements as rows in newdata (after
  removing missing data) or in the original model.frame.

 
}
\author{Charles C. Berry \email{cberry@ucsd.edu}}

\seealso{ \code{\link{bqtl}}}

\examples{

data(little.ana.bc)

fit.pheno <- bqtl(bc.phenotype~locus(15)+locus(42),little.ana.bc)

summary(predict(fit.pheno))

genotype.grid <- expand.grid( c(-1,1), c(-1,1) )     # set up a grid
names(genotype.grid) <- map.names( fit.pheno )       # use matching names

fit.vals <- predict( fit.pheno, genotype.grid )      # make predictions
cbind( genotype.grid, fit.vals )                     # print them!

}

\keyword{methods}
\eof
\name{predict.linear.bayes}
\alias{predict.linear.bayes}
\alias{fitted.linear.bayes}
\alias{residuals.linear.bayes}
\title{ Residuals or Predicted Values for linear.bayes objects }
\description{
 The \code{linear.bayes} object returns fitted coefficients. These are
 used to construct predicted values. Since the fitting process for
 \code{linear.bayes} objects is based on moments of centered variables,
 the 'intercept' is lost; see `Details' below.
}
\usage{
\method{residuals}{linear.bayes}(object, newdata, return.resids)
\method{predict}{linear.bayes}(object)
\method{fitted}{linear.bayes}(object)
}
\synopsis{
predict.linear.bayes(object, newdata=lb.call$ana.obj, return.resids=FALSE,...)
}
\arguments{
  \item{object}{An object returned by \code{linear.bayes} }
  \item{newdata}{Optional \code{data.frame} in which to do the calculations }
  \item{return.resids}{Not usually set by the user. } }

\details{ Since the linear.bayes \code{object} is based on a moment
matrix, some information is lost thsat must be reconstructed or
assumed. The intercept and possibly the coefficients for control
variates are aong these. Also, when the call to \code{linear.bayes}
supplied the moment matrix rather than formulae with which to create
one, then it is unclear what variable was used as the regressand and
hence which variable to use in ofrming residuals. So, in that case,
\code{residuals} will report an error }

\value{
  A vector of predicted values or residuals
}
\author{ Charles C. Berry \email{cberry@ucsd.edu}}

\seealso{ \code{\link{linear.bayes}}}

\keyword{methods}
\eof
\name{residuals.bqtl}
\alias{residuals.bqtl}
\title{ Residuals from QTL models}
\description{
 The phenotype data, estimated coefficients, and expected locus values
are used to find fitted values for the QTL model
}
\synopsis{residuals.bqtl(object,...)}
\usage{
\method{residuals}{bqtl}(object)

}
\arguments{
  \item{object}{ An object of class \code{\link{bqtl}}}}
}
\details{
 The estimated coefficients for a specific QTL model fit are used along
 with the  expected locus values (conditionally on the marker values)
 are used to find fitted values for the QTL model; these are subtracted
 from the origianl trait values to get residuals. This is \emph{not} the
 only  way in which such fits could be obtained; one could condition the
 expected marker values on \emph{both} the trait value and the marker
 values. One could also define fitted values for specific genotype
 combinations, e.g. for a backcross with k animals and a two gene model
 4 fitted values could be determined for each animal leading to 2*2*k
 residuals. 
}
\value{ A vector with as many elements trait values used in the original
  fitted model.

 
}
\author{Charles C. Berry \email{cberry@ucsd.edu}}

\seealso{ \code{\link{bqtl}}}

\examples{

data(little.ana.bc)

fit.pheno <- bqtl(bc.phenotype~locus(15)+locus(42),little.ana.bc)

summary(residuals(fit.pheno))

plot( fitted( fit.pheno ), residuals( fit.pheno) )

\testonly{rm(little.ana.bc,fit.pheno)}

}
\keyword{methods}
\eof
\name{summary.adj}
\alias{summary.adj}

\title{Summarize Laplace approximations }
\description{ The linear approximations of \code{swap} are much improved
  by the use a Laplace approximations for loci that are not
  markers. This function combines the results of a call like
  \code{bqtl(y~configs(swap.obj),\dots)} with the data in
  \code{swap.obj} to provide improved posteriors, et cetera} 
}
\synopsis{
summary.adj(object, n.loc, coef.znames, mode.names=c("add", "dom"),
imp.denom=NULL, swap.obj=NULL,...)
}
\usage{

\method{summary}{adj}(object, n.loc, coef.znames, mode.names=c("add",
"dom"), imp.denom=NULL, swap.obj=NULL)
}
\arguments{
  \item{object}{Typically, this is the result of a call like
  \code{bqtl(y~configs(swap.obj),\dots)}  }
  \item{n.loc}{The number of genes in this model }
  \item{coef.znames}{\code{map.names} for the sample space }
  \item{mode.names}{\code{NULL} except for "F2", in which case it is
    uusally c("add","dom") }
  \item{imp.denom}{Optional, and only used when some sampling scheme
    other than the default MCMC generates \code{object} }
  \item{swap.obj}{The result of a call to \code{swap} }
}
\details{
  There are a lot of details. This sections nneds to be revised to
  reflect them.
}
\value{
A list with components
  \item{adj }{This multiplier adjusts the posterior odds for k vs k-1
    gene models }
  \item{var }{An estimate of the variance of \code{adj}}
  \item{coef}{Posterior means of coefficients}
  \item{loc}{Marginal Posterior for location for k gene model}
\item{hk.ratio.mean}{argh! I need to look this up}
}
\references{Berry C.C. (1998) Computationally Efficient Bayesian QTL Mapping in
  Experimental Crosses. \emph{ASA Proceedings of the Biometrics
    Section,} 164-169. 
}
\author{Charles C. Berry \email{cberry@ucsd.edu} }
\keyword{methods}

\eof
\name{summary.bqtl}
\alias{summary.bqtl}

\title{Summarize bqtl object }
\description{
  Extract coefficients (and related stats), loglikelihood, and residual
  standard error of the trait.  
}
\usage{
\method{summary}{bqtl}(object,\dots)
}

\arguments{
  \item{object}{The result of \code{link{bqtl}} }
  \item{\dots}{ Currently not used}

}
\value{
  A list containing
  \item{coefficients }{Either a vector of regression coefficents, or if
    {object} was created via \code{bqtl(\dots,return.hess=TRUE)}, then
    a matrix with coefficients, standard errors, t-statistics, and p-values}
  \item{loglik }{
    the loglikelihood or log posterior}
  \item{std.res}{The residual standard deviation of the trait}
  \item{N}{The counts of all observations, the number omitted, and the
    number used in the fit}
}

\author{Charles C. Berry \email{cberry@ucsd.edu}}
\examples{
data(little.ana.bc)
fit <- bqtl( bc.phenotype~locus(4)*locus(45), little.ana.bc,
return.hess=TRUE )
summary(fit)
\testonly{rm(little.ana.bc,fit)}
}
\keyword{methods}

\eof
\name{summary.map.frame}
\alias{summary.map.frame}
\alias{summary.analysis.object}

\title{ Summary methods for basic data objects }
\description{
 Provide a simple report on the data structure
}
\synopsis{summary.map.frame(object,...)}
\usage{
\method{summary}{map.frame}(object)
}

\arguments{
  \item{object}{ A \code{map.frame} or \code{analysis.object} }
}

\value{
 a list
}
\author{Charles C. Berry \email{cberry@ucsd.edu} }
\keyword{methods}

\eof
\name{summary.swap}
\alias{summary.swap}

\title{Summarize Gibbs samples for a k-gene model }
\description{
Calculate marginal posteriors for location, posterior means for
coefficients, and the Bayes Factor for k vs k-1 genes  
}
\synopsis{
summary.swap(object, method, ncoef, nloc, ...)}
\usage{
\method{summary}{swap}(object, method=NULL, ncoef=length(sc.obj$alt.coef), nloc=sc.obj$nloc)
}

\arguments{
  \item{object}{ The result of \code{\link{swap}} }
  \item{method}{Optional. One of the supported methods, see \code{\link{make.analysis.obj}} }
  \item{ncoef}{Optional. The number of coefficients in the class of
    models. Typically, \code{2*nloc} for \code{method=="F2"} and
    \code{nloc} for all other methods  }
  \item{nloc}{Optional. The number of loci in the sample space. }
}
\value{
  A list with components:
  \item{loc.posterior }{A vector of (marginal) posterior odds for each
    locus compared to a no gene model}
  \item{coefs}{Posterior means of coefficients.}
  \item{ratio}{A list with components \code{mean}, an estimate of the
  Bayes Factor for k versus k-1 gene models, and \code{var}, an estimate
  of its variance.}
}
\author{Charles C. Berry \email{cberry@ucsd.edu} }

\keyword{methods}

\eof
\name{swap}
\alias{swap}

\title{ MCMC sampling of multigene models}
\description{
Given a k-gene model as a starting point, one gene is deleted and
another is sampled in its place. This is done using an approximation to
the posterior. Then another gene is deleted and another sampled,\dots

}
\usage{
swap(varcov, invars, rparm, nreps, ana.obj, ...)
}

\arguments{
  \item{varcov}{The result of \code{\link{make.varcov}} }
  \item{invars}{ Vector of
    numerical indexes of \code{ana.obj$reg.names} telling which
    variables to start in the model. The first of these is immediately
    removed, so it is merely a placeholder.  The number of genes in the
    model is therefore \code{k <- length(invars)} (except when
    \code{ana.obj$method=="F2"} when it is \code{k <-
      length(unique(col(ana.obj$reg.names)[invars]))})  }
  \item{rparm}{Scalar or vector with \code{nrow(varcov$var.x)} elements;
    the 'ridge' parameters for the independent variables - larger values
    imply more shrinkage or a more concentrated prior for the regresion
    coefficients.  }
  \item{nreps}{ How many cycles (of \code{k} samples each) to perform.  }
  \item{ana.obj}{ An \code{analysis.object} --- see \link{make.analysis.obj}}
  \item{\dots}{Additional arguments override the default choices of
    candidate loci (\code{locs}), prior for locus (\code{locs.prior}),
    or method specified by \code{ana.obj}. Also, the default prior for
    model (\code{combo.prior}) when \code{ana.obj$method=="F2" can be
      overridden. See \link{swapbc1} and \link{swapf2} for details. }
}}
\details{
   An MCMC sampler for loci using the object of \code{ make.varcov } is
  executed.  This sampler uses the exact posterior probability under the
  assumed correctness of the regression model using expected genotypes
  given marker values.  This amounts to linearizing the likelihood with
  respect to the  (possibly unknown) locus states.  For models where the
  loci are fully informative markers this is the true posterior.

  The chain is implemented as follows: given a set of regressor
variables to start, one variable is removed, all regressor
variables not in the model are examined to determine the effect of each
on the posterior.  One variable is sampled.  The process is repeated until
each variable has been removed and a new one sampled in its place
(possibly the same variable that was removed is sampled).  And this whole
cycle is repeated \code{nreps} times.  
}
\value{
  A list with components:
  \item{config}{ A k by k by nreps array (or, for
    \code{ana.obj$method=="F2"}, a 2k by k by nreps array) of the
    locations (variables) sampled in each iteration.} 
  \item{posteriors}{ A vector of length \code{k*nreps} with the
    posteriors of the models.} 
  \item{coefs}{A k by k matrix of the regression coefficients(or, for
    \code{ana.obj$method=="F2"}, a 2k by nreps matrix).}
  \item{call}{The call to \code{swap}}
  \item{cond}{The \code{k*nreps} posterior probabilities of the k-1 gene
    models.}
  \item{marg}{The \code{k*nreps} marginal posteriors for all k gene
    models that could be formed  using  the current k-1 gene model}
  \item{alt.marginal}{A vector with \code{length(locs)} (or \code{2*length(locs)}) elements.  At
    each step, the posterior associated with  each candidate locus is
    added to an element of this vector.  After all steps are finished,
    the result is normalized to sum to one.  This turns out to be a
    stable estimate of the marginal posterior. }
  \item{alt.coef}{A vector with \code{length(locs)} (or
    \code{2*length(locs)}) elements.  At each step, the product of each
    posterior times the coefficient(s) associated with a candidate locus
    is added to an element of this 
    vector.  After all steps are finished, the result is normalized by
    the total marginal posterior.  This turns out to be a stable
    estimate of the marginal (over all models) posterior mean of the
    regression coefficients. }
}
\references{Berry C.C. (1998) Computationally Efficient Bayesian QTL Mapping in
  Experimental Crosses. \emph{ASA Proceedings of the Biometrics
    Section,} 164-169. 
}
\author{Charles C. Berry \email{cberry@ucsd.edu} }
\examples{
data( little.ana.bc )
little.vc <- varcov( bc.phenotype~locus(all), little.ana.bc)
little.4 <- swap( little.vc, c(1,15,55,75), rparm=1, 50, little.ana.bc )
little.4.smry <- summary( little.4 )
print(c("Bayes Factor (3 vs 4)"=little.4.smry$ratio$mean))
par(mfrow=c(3,2))
plot( little.ana.bc, little.4.smry$loc.posterior, type="h",
 ylab="E(genes)" )
rm(little.4,little.vc,little.ana.bc)
}
\keyword{regression}
\eof
\name{swapbc1}
\alias{swapbc1}
\title{
  Sample BC1 or Recombinant Inbred loci  via approximate posterior.
}
\description{
  An MCMC sampler for loci using precomputed dispersion matrices,
  various priors, and a pre-selected set of variables.  For use with BC1
  (backcross) designs and recombinant inbred lines.
}
\usage{
swapbc1(varcov, invars, rparm, nreps, ana.obj, locs=NULL,
locs.prior=NULL, tol=1e-10 )

}
\arguments{
  \item{varcov}{ The result of \code{ \link{make.varcov}}}
  \item{rparm}{ Scalar or vector with \code{nrow(varcov$var.x)} elements;
    the 'ridge' parameters for the independent variables - larger values
    imply more shrinkage or a more concentrated prior for the regresion
    coefficients. }
  \item{nreps}{How many cycles of MCMC to perform}
  \item{ana.obj}{A object produced by \code{\link{make.analysis.obj}}}
  \item{invars}{
    Which variables to start in the model. The first of these is
    immediately removed, so it is merely a placeholder.  The number of
    genes in the model is therefore \code{k <- length(invars)}}
  \item{locs}{
    The columns of \code{varcov\$var.x} to use.  The default uses all of
    them.} 
  \item{locs.prior}{
    The prior mass to associate with each variable.  Typically, these sum
    to one, but sometimes they might each be set to one (as in computing
    lod scores). }
  \item{tol}{Used in forming QR decomposition.  Let it be.}
}
\details{
  An MCMC sampler for loci using the object of \code{ make.varcov } is
  executed.  This sampler uses the exact posterior probability under the
  assumed correctness of the regression model using expected genotypes
  given marker values.  This amounts to linearizing the likelihood with
  respect to the  (possibly unknown) locus states.  For models where the
  loci are fully informative markers this is the true posterior.

  The chain is implemented as follows: given a set of regressor
variables to start, one variable is removed, all regressor
variables not in the model are examined to determine the effect of each
on the posterior.  One variable is sampled.  The process is repeated until
each variable has been removed and a new one sampled in its place
(possibly the same variable that was removed is sampled).  And this whole
cycle is repeated \code{nreps} times.  
}
\value{
  A list with components:
  \item{config}{ A k by k by nreps array of the locations sampled in
    each iteration. }
  \item{posteriors}{ A vector of length \code{k*nreps} with the
    posteriors of the models.} 
  \item{coefs}{A k by k matrix of the regression coefficients.}
  \item{call}{The call to \code{swapbc1}}
  \item{cond}{The \code{k*nreps} posterior probabilities of the k-1 gene
    models.}
  \item{marg}{The \code{k*nreps} marginal posteriors for all k gene
    models that could be formed  using  the current k-1 gene model}
  \item{alt.marginal}{A vector with \code{length(locs)} elements.  At
    each step, the posterior associated with  each candidate locus is
    added to an element of this vector.  After all steps are finished,
    the result is normalized to sum to one.  This turns out to be an
    exceedingly stable estimate of the marginal posterior. }
  \item{alt.coef}{A vector with \code{length(locs)} elements.  At
    each step, the product of each posterior times the coefficient
    associated with a candidate locus is 
    added to an element of this vector.  After all steps are finished,
    the result is normalized by the total marginal posterior.  This turns
    out to be an exceedingly stable estimate of the marginal (over all
    models) posterior mean of the regression coefficients. }
}
\seealso{
  \code{\link{swapf2}}
}
\references{Berry C.C. (1998) Computationally Efficient Bayesian QTL Mapping in
  Experimental Crosses. \emph{ASA Proceedings of the Biometrics
    Section,} 164-169.
}
\author{Charles C. Berry \email{cberry@ucsd.edu} }
\keyword{utilities}
\eof
\name{swapf2}
\alias{swapf2}
\title{
  Sample F2 loci  via approximate posterior 
}
\description{
  An MCMC sampler for loci using precomputed dispersion matrices,
  various priors, and a pre-selected set of variables. For use with F2
  intercross design.

Using precomputed dispersion matrices, various priors, and a pre-selected set of variables, one locus is removed, all other loci are examined to determine the effect of each on the posterior. One locus is sampled. The process is repeated until each locus has been removed and a new one sampled in its place (possibly the same one that was removed is sampled). 
}
\usage{
swapf2(varcov, invars, rparm, nreps, ana.obj, locs = <<see below>>, 
    locs.prior = <<see below>>, combo.prior = <<see below>>, tol = 1e-10)
} 

\arguments{
  \item{varcov}{ The result of \code{ make.varcov }. The columns of
    \code{varcov$var.x} must alternate 'additive' and 'dominance' terms.}
  \item{rparm}{
    The 'ridge' parameters for the independent variables - larger values
    imply more shrinkage or a more concentrated prior for the regresion
    coefficients. }
  \item{nreps}{How many cycles of MCMC to perform}
  \item{ana.obj}{A object produced by \code{\link{make.analysis.obj}}}
  \item{invars}{A vector of variable indexes. This determines which
    variables to start in the model. If both additive and 
    dominance terms are to be used, they should occupy adjacent
    locations in \code{invars}. The variable(s) associated with the
    first locus is (are) immediately removed, serving only as
    placeholder(s). If there are k loci associated with the variables,
    then all subsequent models have k loci, although the nuimber of
    variables may vary according to the selection of one or both of the
    'additive' or 'dominance' terms.  } 
  \item{locs}{
    The pairs of columns of \code{varcov$var.x} to use. The default
    uses all of them.}
  \item{locs.prior}{ Vector whose elements are 
    the prior masses to associate with each locus. Typically, these sum
    to one, but sometimes they might each be set to one (as in computing
    lod scores). The default value sets them all to 1.0.
     }
  \item{combo.prior}{
    The prior probability for each term or combination of terms for the
    phenotypic effect at a locus. Typically, there will be three of
    these - one for the 'additive' term (linear in number of alleles
    from one parent strain), the 'dominance' term (quadratic in allele
    number), or both terms. The default sets them all to 1/3.
  }

  \item{tol}{Used in forming QR decomposition. Let it be.}
}

\value{
  A list with components:
  \item{configs}{ A 2k by k by nreps array of indexes of variables sampled in
    each of the nreps iterations. Models using less than 2k variables
    \code{configs[,i,j]} will contain one or more zeroes in the last
    position(s) }
  \item{posteriors}{ A vector of length \code{k*nreps} with the
    posteriors of the models sampled.} 
  \item{coefs}{A 2k by k by nreps matrix of the regression
    coefficients. Models using less than 2k variables 
    \code{configs[,i,j]} will contain one or more zeroes in the last
    position(s) }
  \item{call}{The call to \code{swapf2}}
  \item{cond}{The \code{k*nreps} posterior probabilities of the k-1 gene
    models.} 
  \item{marg}{The \code{k*nreps} marginal posteriors for all k gene
    models that could be formed using the current k-1 gene model)}
  \item{alt.marginal}{A vector with \code{length(locs)} elements. At
    each step, the posterior associated with  each candidate locus is
    added to an element of this vector. After all steps are finished,
    the result is normalized to sum to one. This turns out to be an
    exceedingly stable estimate of the relative marginal posterior. }
  \item{alt.coef}{A vector with \code{2*length(locs)} elements. At
    each step, the product of each posterior times the coefficient
    associated with a candidate variable is 
    added to an element of this vector. After all steps are finished,
    the result is normalized by the total marginal posterior. This turns
    out to be an rather stable estimate of the marginal (over all
    models) posterior mean of the regression coefficients. }
}

\details{
  A call to \code{swapf2} is used to obtain the results. This function
  is really just a wrapper. 
}
\seealso{
  \code{\link{swapbc1}}
}

\references{Berry C.C. (1998) Computationally Efficient Bayesian QTL Mapping in
  Experimental Crosses. \emph{ASA Proceedings of the Biometrics
    Section,} 164-169.
}
\author{Charles C. Berry \email{cberry@ucsd.edu} }

\keyword{utilities}
\eof
\name{twohk}
\alias{twohk}

\title{ One and Two Gene Models Using Linearized Posterior }
\description{
 Fits all one and two gene models (without interactions aka 'epistasis')
 in an intercross, backcross, or recombinant inbred line. Uses a linear
 approximation to the likelihood, i.e. the expected allele states are
 used. 
}
\usage{
twohk(varcov, ana.obj, ...)
}

\arguments{
 \item{varcov}{ An object produced by \code{ \link{make.varcov}} }
 \item{ana.obj}{An \code{analysis.object} --- see \code{make.analysis.obj} }
 \item{\dots}{Additional arguments override the default choices of
    candidate loci (\code{locs}), prior for locus (\code{locs.prior}),
    or method specified by \code{ana.obj}:
\code{locs}{A vector indexing the loci to use.}
  \code{locs.prior}{ 
    The prior mass to  associate with each locus. Typically, these sum
    to one, but sometimes they might each be set to one (as in computing
    lod scores). }
\code{combo.prior}{Only valid for \code{ana.obj$method=="F2"}. 
    The prior probability for each term or combination of terms for the
    phenotypic effect at a locus. Typically, there will be three of
    these - one for the 'additive' term (linear in number of alleles
    from one parent strain), the 'dominance' term (quadratic in allele
    number), or both terms. The default sets them all to 1/3.}
}}
\details{
  The marginal posterior (integrating over regression parameters and
  dispersion) is calculated for each one and two gene model under the
  assumed correctness of the regression model using expected genotypes
  given marker values. This amounts to linearizing the likelihood with
  respect to the  (possibly unknown) locus states. For models where the
  loci are fully informative markers this is the true posterior.
}
\value{
 A list with components:
 \item{loc.1}{The marginal posterior for each one gene model relative to
   a no gene model.  For
   \code{twohkf2} this is a matrix of 3 columns; the first for models
   with additive terms, the second for dominance terms, and the third
   for both. The sum over all three columns yields the marginal
   posterior for the locus.}
 \item{loc.2}{The marginal posterior for each locus --- obtained by summing
   over all two gene models that include that locus---  relative to
   a no gene model. For
   \code{twohkf2} this is a matrix of 3 columns; the first for models
   with additive terms, the second for dominance terms, and the third for both. }
 \item{coefs.1}{The regression coefficients for the genetic effect for 
   each locus. For \code{twohkf2}, this is a matrix with two rows; the
   first is for the 'additive effect' and the second is for the
   'dominance' effect.}
 \item{coefs.2}{The marginal posterior mean of regression coefficients
   for the genetic effect for each locus - obtained by averaging over
   all two gene models that include that locus according to the
   posterior masses. For \code{twohkf2}, this is a matrix with two rows; the
   first is for the 'additive effect' and the second is for the
   'dominance' effect.}
}
\references{
  Haley C.S. and Knott S.A. (1992) A simple regression method for mapping
  quantitative trait loci in line crosses using flanking
  markers. \emph{Heredity} \bold{69},315-324. } 
\author{Charles C. Berry \email{cberry@ucsd.edu} }

\examples{
data(little.ana.bc)
little.vc<-make.varcov(little.ana.bc$data[,little.ana.bc$reg.names],
  little.ana.bc$data$bc.phenotype)
little.2<- twohk(little.vc,little.ana.bc,rparm=1)
print( c(odds.1=sum(little.2$loc.1),odds.2=sum(little.2$loc.2)) )
par(mfrow=c(3,2))
little.pe <- 2 * little.2$loc.2 / sum(little.2$loc.2)   #locus-wise posterior expectation
plot(little.ana.bc,little.pe,type="h",ylab="E(genes")
rm(little.2,little.vc,little.pe,little.ana.bc)
}
\keyword{models}
\eof
\name{twohkbc1}
\alias{twohkbc1}
\alias{twohkf2}

\title{ One and Two Gene Models Using Linearized Posterior}
\description{
  Fits all one and two gene models (without interactions aka
  'epistasis') in an intercross, backcross, or recombinant inbred
  line. Uses a linear 
  approximation to the likelihood, i.e. the expected allele states are
  used.
}
\usage{
twohkbc1(varcov, rparm, locs=<<see below>> ), locs.prior=<<see below>> )

twohkf2(varcov, ana.obj, rparm, locs=<<see below>>, locs.prior=<<see below>>,
combo.prior=<<see below>>) 
}
\arguments{
  \item{varcov}{ An object produced by \code{ \link{make.varcov}} }
  \item{ana.obj}{An object produced by \code{ \link{make.analysis.obj}}}
 \item{rparm}{ The 'ridge' parameters for the independent variables -
   larger values imply more shrinkage or a more concentrated prior for
   the regresion coefficients. } 
 \item{locs}{ The columns (or pairs of columns for \code{twohkf2}) of
   \code{varcov\$var.x} to use. The default uses all of them.}
  \item{locs.prior}{ 
    The prior mass to  associate with each locus. Typically, these sum
    to one, but sometimes they might each be set to one (as in computing
    lod scores). }
\item{combo.prior}{Only valid for \code{twohkf2}. 
    The prior probability for each term or combination of terms for the
    phenotypic effect at a locus. Typically, there will be three of
    these - one for the 'additive' term (linear in number of alleles
    from one parent strain), the 'dominance' term (quadratic in allele
    number), or both terms. The default sets them all to 1/3.
  }
}
\details{
  The marginal posterior (integrating over regression parameters and
  dispersion) is calculated for each one and two gene model under the
  assumed correctness of the regression model using expected genotypes
  given marker values. This amounts to linearizing the likelihood with
  respect to the  (possibly unknown) locus states. For models where the
  loci are fully informative markers this is the true posterior.
}
\value{
 A list with components:
 \item{loc.1}{The marginal posterior for each one gene model.  For
   \code{twohkf2} this is a matrix of 3 columns; the first for models
   with additive terms, the second for dominance terms, and the third
   for both. The sum over all three columns yields the marginal
   posterior for the locus.}
 \item{loc.2}{The marginal posterior for each locus - obtained by summing
   over all two gene models that include that locus. For
   \code{twohkf2} this is a matrix of 3 columns; the first for models
   with additive terms, the second for dominance terms, and the third for both. }
 \item{coefs.1}{The regression coefficients for the genetic effect for 
   each locus. For \code{twohkf2}, this is a matrix with two rows; the
   first is for the 'additive effect' and the second is for the
   'dominance' effect.}
 \item{coefs.2}{The marginal posterior mean of regression coefficients
   for the genetic effect for each locus - obtained by averaging over
   all two gene models that include that locus according to the
   posterior masses. For \code{twohkf2}, this is a matrix with two rows; the
   first is for the 'additive effect' and the second is for the
   'dominance' effect.}
}
\references{
  Haley C.S. and Knott S.A. (1992) A simple regression method for mapping
  quantitative trait loci in line crosses using flanking
  markers. \emph{Heredity} \bold{69},315-324. } 
\author{Charles C. Berry \email{cberry@ucsd.edu} }
\keyword{utilities}
\eof
\name{bqtl.fitter}
\alias{bqtl.fitter}

\title{Get loglikelihoods for many models of a common form }
\description{
For a single type of model, this function evaluates multiple models that
differ only in terms of the loci involved. The looping is all done by
internal C functions, so this is faster than simply using \code{bqtl} to
do the same thing.
}
\usage{
bqtl.fitter(setup, loc.mat, ana.obj)
}

\arguments{
  \item{setup}{The object returned by  \code{bqtl( <...> , setup=TRUE )} }
  \item{loc.mat}{A matrix of locus numbers, s.t. \code{nrow(loc.mat)}
    equals the number of loci in \code{setup} }
  \item{ana.obj}{An \code{analysis.object}. Usually the one used in \code{setup} }
}
\details{
In order to avoid the computational overhead of running large loops of
very repetitive operations in R/S, \code{bqtl.fitter} used after the
\code{setup=TRUE} option in \code{\link{bqtl}} will loop through the
loci specified in \code{loc.mat} using internal C code. This is many
times faster than running the same code via \code{bqtl}.
}
\value{
  For now it only returns the loglikelihood. But it would be trivial to
  build an option that would allow other quantities computed to be
  returned, and this should probably be done. However, some care is
  needed to keep objects from becoming unmanageably large.
}

\author{Charles C. Berry \email{cberry@ucsd.edu} }

\seealso{\code{\link{bqtl}}}

\examples{
data( little.ana.bc )
little.setup <-
bqtl( bc.phenotype~locus(1)*locus(2), little.ana.bc, setup=TRUE )
combos <- t( as.matrix( expand.grid( 1:21, 44:64 ) ) )
little.update <- bqtl.fitter(little.setup, combos, little.ana.bc)
little.res <- matrix( little.update, nr=21 )
image( 1:21, 44:64, little.res )
rm(little.ana.bc, little.update, little.res  )
}

\keyword{models}
\eof
\name{varcov}
\alias{varcov}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Create moment matrices}
\description{
  Create a moment matrix of the marker variables and of the regressors by
  the phenotype variable.  For use in regression modelling on the markers.
}
\usage{
varcov(x, ana.obj, partial=NULL, scope=<<see below>>}
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{A formula to specify the dependent and independent variables
    to be used in subsequent calculations e.g \code{trait ~ locus(.) }}
  \item{ana.obj}{An \code{analysis.object},
    see\code{\link{make.analysis.obj}}  }
  \item{partial}{A formula whose right hand side specifies variables to
    be treated as covariates. }
  \item{scope}{ Usually not explicitly used. Optional vector of variable
    names. } 
}
\details{This is just a wrapper for \code{\link{make.varcov}}.}
\value{
 A list with components
  \item{var.x }{Moment matrix of the marker regressor variables}
  \item{cov.xy }{Moment matrix of the marker regressor variables versus
    the phenotype variable}
  \item{var.y}{The Second central moment of the phenotype variable}
  \item{df}{The degrees of freedom, when no variables are specified in
    \code{partial} it is \code{ sum(subset==TRUE) - 1}
}}
\author{Charles C. Berry \email{cberry@ucsd.edu} }
\note{ It is generally NOT a good idea to do regressions on
  ill-conditioned designs using the moment matrices.  The
  excuse for doing so here is twofold.  First, calculations using this
  method are used to perform importance sampling, so minor numerical
  inaccuracies in computing the probabilites used in sampling get
  straightened out by the importance weights.  Second, it will typically
  be the case that a prior is set on the regression coefficients and
  this results in a positive constant (aka a 'ridge' parameter) being
  added to diagonal of \code{varcov()$var.x} and this reduces the
  ill-conditioning.  Of course the rational for using the method is to
  speed the sampling, and it is very effective at doing so.}
\seealso{The examples in \code{\link{swap}} and \code{\link{twohk}}.}
\keyword{utilities}
\eof
